@@ -1,4 +1,4 @@
-# copyright 2011-2021 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2011-2022 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -161,6 +161,7 @@ class AutoClickAndEditFormView(EntityView):
         """display field to edit entity's `rtype` relation on click"""
         assert rtype
         self._cw.add_css("cubicweb.form.css")
+        self._cw.add_js("cubicweb.ajax.js")
         self._cw.add_js("cubes.inlinedit.js", "cubicweb.edition.js")
         self.entity = entity
         rschema = self._cw.vreg.schema[rtype]
@@ -332,7 +333,7 @@ class ReleditFormHandler(appobject.AppObject):
         }
 
     def _setup_form_arguments(self, form, event_args):
-        for pname, pvalue in event_args.iteritems():
+        for pname, pvalue in event_args.items():
             if pname == "reload":
                 pvalue = json_dumps(pvalue)
             form.add_hidden("__reledit|" + pname, pvalue)
@@ -489,8 +490,8 @@ class ReleditEntityFormHandler(ReleditFormHandler):
         with t.div(
             w,
             id="%s-reledit" % divid,
-            onmouseout="jQuery('#%s').addClass('hidden')",
-            onmouseover="jQuery('#%s').removeClass('hidden')",
+            onmouseout="jQuery('#%s').addClass('hidden')" % divid,
+            onmouseover="jQuery('#%s').removeClass('hidden')" % divid,
             Class="editableFieldValue",
         ):
             with t.div(w, id="%s-value" % divid, Class="editableFieldValue"):
